@@ -41,7 +41,7 @@ $SIG{__WARN__} = sub { warn "Warn: ", @_ };
 $SIG{__DIE__}  = sub { die "Error: ", @_ };
 
 # Global variables:
-our $VERSION   = '0.22';
+our $VERSION   = '0.23';
 our $share_dir = dist_dir('Convert-Pheno');
 
 # SQLite database
@@ -372,9 +372,13 @@ sub omop2bff {
 
             if ( $ext =~ m/\.sql/i ) {
 
+                print "> Param: --max-lines-sql = $self->{max_lines_sql}\n" if $self->{verbose};
+
                 # --no-stream
                 if ( !$self->{stream} ) {
 
+                    print "> Mode : --no-stream\n\n" if $self->{verbose};
+
                     # We read all tables in memory
                     $data = read_sqldump( { in => $file, self => $self } );
 
@@ -385,7 +389,7 @@ sub omop2bff {
                 # --stream
                 else {
 
-                    print "> Running in --stream mode\n\n" if $self->{verbose};
+                    print "> Mode : --stream\n\n" if $self->{verbose};
 
                     # We'll ONLY load @stream_ram_memory_tables
                     # in RAM and the other tables as $fh
@@ -393,6 +397,9 @@ sub omop2bff {
                     $data = read_sqldump( { in => $file, self => $self } );
                 }
 
+                # Misc print
+                print "> Parameter --max-lines-sql set to: $self->{max_lines_sql}\n\n" if $self->{verbose};
+
                 # We keep the filepath for later
                 $filepath = $file;
 
